@@ -6,12 +6,15 @@ from fidesctl.cli.cli import (
     apply,
     delete,
     evaluate,
-    find,
     generate_dataset,
     get,
+    init_db,
     ls,
+    parse,
     ping,
+    reset_db,
     view_config,
+    webserver,
 )
 from fidesctl.core.config import get_config
 
@@ -19,6 +22,7 @@ CONTEXT_SETTINGS = dict(help_option_names=["-h", "--help"])
 
 
 @click.group(context_settings=CONTEXT_SETTINGS)
+@click.version_option(version=fidesctl.__version__)
 @click.option(
     "--config-path",
     "-f",
@@ -36,20 +40,15 @@ def cli(ctx: click.Context, config_path: str) -> None:
     ctx.obj["CONFIG"] = get_config(config_path)
 
 
-@cli.command()
-def version() -> None:
-    """
-    Get the current Fidesctl version.
-    """
-    click.echo(fidesctl.__version__)
-
-
 cli.add_command(apply)
 cli.add_command(delete)
 cli.add_command(evaluate)
-cli.add_command(find)
 cli.add_command(generate_dataset)
 cli.add_command(get)
+cli.add_command(init_db)
 cli.add_command(ls)
+cli.add_command(parse)
 cli.add_command(ping)
+cli.add_command(reset_db)
 cli.add_command(view_config)
+cli.add_command(webserver)
