@@ -1,34 +1,30 @@
 """
-This module handles everything related to parsing models,
+This module handles everything related to parsing resources into Pydantic models,
 either from local files or the server.
 """
 from typing import List, Dict
 
-from pydantic import ValidationError
-
 from fideslang import model_map, FidesModel, Taxonomy
 from fidesctl.core.utils import echo_red
 
 
-def parse_manifest(
+def parse_dict(
     resource_type: str, resource: Dict, from_server: bool = False
 ) -> FidesModel:
     """
     Parse an individual resource into its Python model.
     """
     resource_source = "server" if from_server else "manifest file"
-    try:
-        parsed_manifest = model_map[resource_type].parse_obj(resource)
-    except ValidationError as err:
-        echo_red(f"Failed to parse resource: {resource} with the following errors:")
-        raise SystemExit(err) from err
-    except KeyError as err:
+    if resource_type not in list(model_map.keys()):
         echo_red(f"This resource type does not exist: {resource_type}")
         raise SystemExit
+
+    try:
+        parsed_manifest = model_map[resource_type].parse_obj(resource)
     except Exception as err:
         echo_red(
-            "Failed to parse {} from {} with fides_key: {}".format(
-                resource_type, resource_source, resource["fides_key"]
+            "Failed to parse {} from {}:\n{}".format(
+                resource_type, resource_source, resource
             )
         )
         raise err
@@ -39,11 +35,10 @@ def load_manifests_into_taxonomy(raw_manifests: Dict[str, List[Dict]]) -> Taxono
     """
     Parse the raw resource manifests into resource resources.
     """
-
     taxonomy = Taxonomy.parse_obj(
         {
             resource_type: [
-                parse_manifest(resource_type, resource) for resource in resource_list
+                parse_dict(resource_type, resource) for resource in resource_list
             ]
             for resource_type, resource_list in raw_manifests.items()
         }
